import sys
import typing
from pathlib import Path

import PySide6
import shiboken6
from PySide6.QtWidgets import QWidget

_INSTALL_LOCATION = Path(__file__).parent

from .pyside6_qtermwidget import QTermWidget as _QTermWidget


class QTermWidget(_QTermWidget):
    @typing.overload
    def __init__(self, parent: QWidget | None = None) -> None: ...

    @typing.overload
    def __init__(self, startnow: int, parent: QWidget | None = None) -> None: ...

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._post_init()

    def _post_init(self):
        self.addCustomColorSchemeDir(str(_INSTALL_LOCATION / "color-schemes"))
        self.setCustomKeyBindingsDir(str(_INSTALL_LOCATION / "kb-layouts"))
        match sys.platform:
            case "linux":
                platform = "linux"
            case "darwin":
                platform = "macbook"
            case _:
                platform = "default"
        self.setKeyBindings(platform)



import logging
import os
import sys
from pathlib import Path
from types import SimpleNamespace

import PySide6
import shiboken6
from shibokensupport.signature.lib.pyi_generator import generate_pyi

pyside_path = Path(PySide6.__file__).parent
shiboken_path = Path(shiboken6.__file__).parent


def _symlink(target, link_name):
    try:
        # in a subsequent build on macos the symlink may already be there
        # or not, we don't care
        os.remove(link_name)
    except FileNotFoundError:
        ...
    os.symlink(target, link_name)


def main():
    # get install dir from script invocation
    os.chdir(sys.argv[1])
    # allow importing the module from there
    sys.path.insert(0, os.getcwd())
    # fake the env of the installed file for loading pyside libs
    _symlink(pyside_path, f"{os.getcwd()}/../PySide6")
    _symlink(shiboken_path, f"{os.getcwd()}/../shiboken6")
    print(os.getcwd())
    print(os.listdir())
    options = SimpleNamespace()
    options.quiet = False
    options.module = "pyside6_qtermwidget"
    options.outpath = sys.argv[1]
    module = options.module
    outpath = options.outpath
    logging.basicConfig(level=logging.DEBUG)
    logger = logging.getLogger("pyi_generator")
    options._pyside_call = True
    options.is_ci = False

    options.logger = logger
    generate_pyi(module, outpath, options=options)


if __name__ == "__main__":
    main()



from pathlib import Path

import PySide6
import shiboken6
import shiboken6_generator

shiboken_root = Path(shiboken6.__file__).parent
pyside_root = Path(PySide6.__file__).parent
shiboken6_generator_root = Path(shiboken6_generator.__file__).parent

print("Shiboken root:", shiboken_root)

shiboken_include = shiboken_root / "include"
print("Shiboken include:", shiboken_include)
print("Shiboken headers:")
for p in shiboken_include.glob("*"):
    print("  ", p.name)

print("\nShiboken6 Generator root:", shiboken6_generator_root)
print("Shiboken6 Generator include:", shiboken6_generator_root / "include")
print("Shiboken6 Generator headers:")
for p in (shiboken6_generator_root / "include").glob("*"):
    print("  ", p.name)

print("\nPySide root:", pyside_root)
print("PySide include:", pyside_root / "include")
print("PySide headers:")
for p in (pyside_root / "include").glob("*"):
    print("  ", p.name)
